var VISIBLE_OPACITY = 1;
var MIN_SCALE = 0.6;
var MAX_SCALE = 10;
var INITIAL_SCALE = 1;
var getDistanceFromLastPosition = function (lastPosition, distancePosition) {
    var x = lastPosition.x, y = lastPosition.y;
    var dx = distancePosition.dx, dy = distancePosition.dy;
    return { dx: dx - x, dy: dy - y };
};
var getImagePositionFromDistanceInScale = function (scale, position, distancePosition) {
    var dx = distancePosition.dx, dy = distancePosition.dy;
    var x = position.x, y = position.y;
    return { x: x + dx / scale, y: y + dy / scale };
};
var getDistanceBetweenTouches = function (firstFinger, secondFinger) {
    var x0 = firstFinger.pageX, y0 = firstFinger.pageY;
    var x1 = secondFinger.pageX, y1 = secondFinger.pageY;
    var xDistance = Math.abs(x0 - x1);
    var yDistance = Math.abs(y0 - y1);
    var diagonalDistance = Math.sqrt(xDistance * xDistance + yDistance * yDistance);
    return Number(diagonalDistance.toFixed(1));
};
var getZoomFromDistance = function (scale, distanceDiff) {
    var zoom = scale + distanceDiff;
    if (zoom < MIN_SCALE) {
        return MIN_SCALE;
    }
    if (zoom > MAX_SCALE) {
        return MAX_SCALE;
    }
    return zoom;
};
var getPositionFromDistanceInScale = function (_a) {
    var currentPosition = _a.currentPosition, centerDiff = _a.centerDiff, distanceDiff = _a.distanceDiff, zoom = _a.zoom;
    return {
        x: currentPosition.x - (centerDiff.x * distanceDiff) / zoom,
        y: currentPosition.y - (centerDiff.y * distanceDiff) / zoom,
    };
};
var getMaxPosition = function (scale, position, windowLayout) {
    var width = windowLayout.width, height = windowLayout.height;
    var x = position.x, y = position.y;
    var horizontalMax = (width * scale - width) / 2 / scale;
    x = Math.max(-horizontalMax, Math.min(horizontalMax, x));
    var verticalMax = (height * scale - height) / 2 / scale;
    y = Math.max(-verticalMax, Math.min(verticalMax, y));
    return { x: x, y: y };
};
var getCenterPositionBetweenTouches = function (firstTouch, secondTouch, windowLayout) {
    var width = windowLayout.width, height = windowLayout.height;
    var centerX = (firstTouch.pageX + secondTouch.pageX) / 2;
    var centerY = (firstTouch.pageY + secondTouch.pageY) / 2;
    return {
        x: centerX - width / 2,
        y: centerY - height / 2,
    };
};
var getZoomAndPositionFromDoubleTap = function (scale, position, windowLayout) {
    if (scale !== INITIAL_SCALE) {
        return {
            scale: INITIAL_SCALE,
            position: { x: 0, y: 0 },
        };
    }
    var width = windowLayout.width, height = windowLayout.height;
    var doubleClickX = position.pageX, doubleClickY = position.pageY;
    var beforeScale = scale;
    var newScale = 2;
    var diffScale = newScale - beforeScale;
    var x = ((width / 2 - doubleClickX) * diffScale) / scale;
    var y = ((height / 2 - doubleClickY) * diffScale) / scale;
    return {
        scale: newScale,
        position: getMaxPosition(newScale, { x: x, y: y }, { width: width, height: height }),
    };
};
var getOpacityFromSwipe = function (_a) {
    var swipeToDismiss = _a.swipeToDismiss, scale = _a.scale, dy = _a.dy, windowHeight = _a.windowHeight;
    if (swipeToDismiss && scale === INITIAL_SCALE) {
        return (windowHeight - Math.abs(dy)) / windowHeight;
    }
    return VISIBLE_OPACITY;
};
export { VISIBLE_OPACITY, getDistanceFromLastPosition, getImagePositionFromDistanceInScale, getDistanceBetweenTouches, getZoomFromDistance, getPositionFromDistanceInScale, getMaxPosition, getCenterPositionBetweenTouches, getZoomAndPositionFromDoubleTap, getOpacityFromSwipe, };
//# sourceMappingURL=index.js.map